Internationalization
====================

pyramid_jinja2 provides integration with the standard Pyramid i18n
mechanism.  By default it uses the *messages* domain.  Once
the message catalogs are setup according to `Pyramid
Internationlization and Localiztion
<http://docs.pylonsproject.org/projects/pyramid/1.0/narr/i18n.html>`_
regular Jinja2 techniques will work with no extra configuration
required.
